"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SLStore = void 0;
const helpers_1 = require("../helpers");
const Sqlite_1 = require("./Sqlite");
//LocalStorage но на sqlite
class SLStore {
}
exports.SLStore = SLStore;
SLStore.nameTable = process.env.REACT_APP_SQLITE_TABLE_SETTINGS;
SLStore.helperTotalData = ({ status, values, totalData }) => {
    if (status && (values === null || values === void 0 ? void 0 : values.length)) {
        for (let i = 0; i < values.length; i++) {
            let item = values[i];
            Object.assign(totalData, { [item.key]: (0, helpers_1.convertByTypeFromDB)(item.value) });
        }
    }
};
SLStore.setItem = (key, value, options) => {
    return new Promise((resolve, reject) => {
        if (window.cordova) { //INFO: Обновить данные если есть
            let nameTable = SLStore.nameTable;
            Sqlite_1.Sqlite.getData(nameTable, { where: { key } })
                .then(({ status }) => {
                if (status) {
                    Sqlite_1.Sqlite.updateData(nameTable, { key, value, type: typeof value }, { where: { key } })
                        .then(resolve)
                        .catch(reject);
                }
                else {
                    Sqlite_1.Sqlite.setData(nameTable, { key, value, type: typeof value }, options)
                        .then(resolve)
                        .catch(reject);
                }
            })
                .catch(reject);
        }
        else {
            try {
                localStorage.setItem(key, (typeof value === 'object' || typeof value === 'boolean') ? JSON.stringify(value) : value);
                resolve({ status: true, msg: 'Данные сохранены в localStorage' });
            }
            catch (err) {
                reject({ status: false, msg: err });
            }
        }
    });
};
/*-----------------------------------------------------------------------------------------------------*/
SLStore.getItem = (key) => {
    return new Promise((resolve, reject) => {
        if (window.cordova) {
            Sqlite_1.Sqlite.getData(SLStore.nameTable, { where: { key } })
                .then(({ status, msg, values }) => {
                let data = {};
                SLStore.helperTotalData({ status, values, totalData: data });
                resolve({ status, msg, data });
            })
                .catch(reject);
        }
        else {
            try {
                let data = {};
                let item = (0, helpers_1.convertByTypeFromDB)(localStorage.getItem(key));
                console.dir(item);
                if (item) {
                    Object.assign(data, { [key]: item });
                    resolve({ status: true, data, msg: 'Данные из localStorage' });
                    return;
                }
                resolve({ status: false, data, msg: 'Данный ключ в localStorage не найден' });
            }
            catch (err) {
                reject({ status: false, msg: err });
            }
        }
    });
};
/*-----------------------------------------------------------------------------------------------------*/
SLStore.getItems = (options) => {
    return new Promise((resolve, reject) => {
        if (window.cordova) {
            Sqlite_1.Sqlite.getData(SLStore.nameTable, {
                ignoreWhere: { key: options === null || options === void 0 ? void 0 : options.ignoreKeys }
            })
                .then(({ status, msg, values }) => {
                let data = {};
                SLStore.helperTotalData({ status, values, totalData: data });
                resolve({ status, data, msg });
            })
                .catch((err) => {
                console.log('catch getAllLocalSetting: ', err);
                reject(err);
            });
        }
        else {
            try {
                let data = {};
                for (let i = 0; i < localStorage.length; i++) {
                    let keyItem = localStorage.key(i);
                    if (keyItem) {
                        let value = (0, helpers_1.convertByTypeFromDB)(localStorage.getItem(keyItem));
                        Object.assign(data, { [keyItem]: value });
                    }
                }
                if (Object.keys(data).length) {
                    resolve({ status: true, data, msg: 'Все данные из localStorage' });
                }
                resolve({ status: false, data, msg: 'localStorage пуст' });
            }
            catch (err) {
                reject({ status: false, msg: err });
            }
        }
    });
};
/*-----------------------------------------------------------------------------------------------------*/
SLStore.removeItem = ({ keys, ignoreKey }) => {
    return new Promise((resolve, reject) => {
        if (window.cordova) {
            Sqlite_1.Sqlite.removeData(SLStore.nameTable, {
                whereKey: { key: keys },
                ignoreWhere: { key: ignoreKey }
            })
                .then(resolve)
                .catch(reject);
        }
        else {
            try {
                if (keys === null || keys === void 0 ? void 0 : keys.length) {
                    for (let i = 0; i < keys.length; i++) {
                        if (ignoreKey === null || ignoreKey === void 0 ? void 0 : ignoreKey.length) {
                            let isIgnoreKey = ignoreKey.some((key) => key === keys[i]);
                            !isIgnoreKey && localStorage.removeItem(keys[i]);
                        }
                        else {
                            localStorage.removeItem(keys[i]);
                        }
                    }
                    resolve({ status: true, msg: `Успешное удаление ключей localStorage` });
                }
                else if (ignoreKey === null || ignoreKey === void 0 ? void 0 : ignoreKey.length) {
                    for (let i = 0; i < localStorage.length; i++) {
                        let keyLS = localStorage.key(i);
                        let isIgnoreKey = ignoreKey.some((key) => key === keyLS);
                        !isIgnoreKey && keyLS && localStorage.removeItem(keyLS);
                    }
                }
                else {
                    localStorage.clear();
                }
            }
            catch (err) {
                reject({ status: false, msg: err });
            }
        }
    });
};
SLStore.dropAllData = () => {
    return new Promise((resolve, reject) => {
        if (window.cordova) {
            Sqlite_1.Sqlite.dropTable(SLStore.nameTable)
                .then(resolve)
                .catch(reject);
        }
        else {
            try {
                localStorage.clear();
                resolve({ status: true, msg: `Успешное полное удаление данных в localStorage` });
            }
            catch (err) {
                reject({ status: false, msg: err });
            }
        }
    });
};
window.SLStore = SLStore;
